Learn R Programming

metalite.table1 (version 0.4.0)

metalite.table1-package: metalite.table1: Interactive Table of Descriptive Statistics in HTML

Description

Create an interactive table of descriptive statistics in HTML. This table is typically used for exploratory analysis in a clinical study (referred to as 'Table 1').

Arguments

Author

Maintainer: Yilong Zhang elong0527@gmail.com