metalite.table1-package: metalite.table1: Interactive Table of Descriptive Statistics in HTML
Description
Create an interactive table of descriptive statistics in HTML. This table is typically used for exploratory analysis in a clinical study (referred to as 'Table 1').