a shiny.tag.list object that contain a reactable HTML widget for
interactive table of describptive statistics.
Arguments
formula
an object of class "formula".
data
a data frame that contain variables described in the formula.
id
a character value to indicate subject/record id variable name in data.
var_listing
a character vector of additional variables included in the drill down listing.
total
a logical value to display or hide "Total" column.
header
a logical vector with length 1 or same length of the variables in formula to show the Number of xxx row of each variable.
Default is to show the row for the first variable.
download
a character value to enable download button. Allowed values include
"none", "listing", "table", and 'all'.
record_name
a character value to control section title (e.g. "Subjects", "Records").